@@ -1,5 +1,6 @@
 import copy
 import datetime
+import decimal
 import inspect
 import json
 import logging
@@ -22,10 +23,8 @@ from great_expectations.core import (
     RunIdentifier,
     expectationSuiteSchema,
 )
+from great_expectations.core.evaluation_parameters import build_evaluation_parameters
 from great_expectations.core.id_dict import BatchKwargs
-from great_expectations.data_asset.evaluation_parameters import (
-    build_evaluation_parameters,
-)
 from great_expectations.data_asset.util import (
     parse_result_format,
     recursively_convert_to_json_serializable,
@@ -72,7 +71,7 @@ class DataAsset(object):
                 "Autoinspect_func is no longer supported; use a profiler instead (migration is easy!).",
                 category=DeprecationWarning,
             )
-        super(DataAsset, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._config = {"interactive_evaluation": interactive_evaluation}
         self._initialize_expectations(
             expectation_suite=expectation_suite,
@@ -222,16 +221,24 @@ class DataAsset(object):
                 expectation_args = copy.deepcopy(all_args)
 
                 if self._expectation_suite.evaluation_parameters:
-                    evaluation_args = build_evaluation_parameters(
+                    (
+                        evaluation_args,
+                        substituted_parameters,
+                    ) = build_evaluation_parameters(
                         expectation_args,
                         self._expectation_suite.evaluation_parameters,
                         self._config.get("interactive_evaluation", True),
+                        self._data_context,
                     )
                 else:
-                    evaluation_args = build_evaluation_parameters(
+                    (
+                        evaluation_args,
+                        substituted_parameters,
+                    ) = build_evaluation_parameters(
                         expectation_args,
                         None,
                         self._config.get("interactive_evaluation", True),
+                        self._data_context,
                     )
 
                 # Construct the expectation_config object
@@ -294,6 +301,11 @@ class DataAsset(object):
                         "exception_traceback": exception_traceback,
                     }
 
+                if len(substituted_parameters) > 0:
+                    if meta is None:
+                        meta = dict()
+                    meta["substituted_parameters"] = substituted_parameters
+
                 # Add meta to return object
                 if meta is not None:
                     return_obj.meta = meta
@@ -604,6 +616,7 @@ class DataAsset(object):
         discard_include_config_kwargs=True,
         discard_catch_exceptions_kwargs=True,
         suppress_warnings=False,
+        suppress_logging=False,
     ):
         """Returns _expectation_config as a JSON object, and perform some cleaning along the way.
 
@@ -616,6 +629,10 @@ class DataAsset(object):
                 In returned expectation objects, suppress the `include_config` parameter. Defaults to `True`.
             discard_catch_exceptions_kwargs (boolean): \
                 In returned expectation objects, suppress the `catch_exceptions` parameter.  Defaults to `True`.
+            suppress_warnings (boolean): \
+                If true, do not include warnings in logging information about the operation.
+            suppress_logging (boolean): \
+                If true, do not create a log entry (useful when using get_expectation_suite programmatically)
 
         Returns:
             An expectation suite.
@@ -693,7 +710,8 @@ class DataAsset(object):
             settings_message += " settings filtered."
 
         expectation_suite.expectations = expectations
-        logger.info(message + settings_message)
+        if not suppress_logging:
+            logger.info(message + settings_message)
         return expectation_suite
 
     def save_expectation_suite(
@@ -849,7 +867,7 @@ class DataAsset(object):
                 )
                 try:
                     run_time = parse(run_id)
-                except ParserError:
+                except (ParserError, TypeError):
                     pass
                 run_id = RunIdentifier(run_name=run_id, run_time=run_time)
             elif isinstance(run_id, dict):
@@ -983,10 +1001,14 @@ class DataAsset(object):
                         expectation.kwargs.update({"result_format": result_format})
 
                     # A missing parameter will raise an EvaluationParameterError
-                    evaluation_args = build_evaluation_parameters(
+                    (
+                        evaluation_args,
+                        substituted_parameters,
+                    ) = build_evaluation_parameters(
                         expectation.kwargs,
                         runtime_evaluation_parameters,
                         self._config.get("interactive_evaluation", True),
+                        self._data_context,
                     )
 
                     result = expectation_method(
@@ -1218,9 +1240,12 @@ class DataAsset(object):
                     )
                 ]
             except TypeError:
-                partial_unexpected_counts = [
-                    "partial_exception_counts requires a hashable type"
-                ]
+                partial_unexpected_counts = []
+                if "details" not in return_obj["result"]:
+                    return_obj["result"]["details"] = {}
+                return_obj["result"]["details"][
+                    "partial_unexpected_counts_error"
+                ] = "partial_unexpected_counts requested, but requires a hashable type"
             finally:
                 return_obj["result"].update(
                     {
@@ -1266,17 +1291,23 @@ class DataAsset(object):
         Returns:
             success (boolean), percent_success (float)
         """
+        if isinstance(success_count, decimal.Decimal):
+            raise ValueError(
+                "success_count must not be a decimal; check your db configuration"
+            )
+
+        if isinstance(nonnull_count, decimal.Decimal):
+            raise ValueError(
+                "nonnull_count must not be a decimal; check your db configuration"
+            )
 
         if nonnull_count > 0:
-            # percent_success = float(success_count)/nonnull_count
             percent_success = success_count / nonnull_count
 
             if mostly is not None:
                 success = bool(percent_success >= mostly)
-
             else:
                 success = bool(nonnull_count - success_count == 0)
-
         else:
             success = True
             percent_success = None
